; Program :           DSP56002EVM Ham Modem Hardware Test Program
;
;           Simple serial port echo program to test wiring etc to/from
;           EVM host serial port. Every character typed on PC will be echoed
;           back to the PC and the PTT LED will flash once. The interface board
;           used was the evmawk.sch by ZS6AWK. (based on KC7WW's version)
;           Use a terminal program on PC set to 19200 baud for comms to EVM.
;           A terminal program like serial.exe (ALEFNUL) is a good choice.
;           TERM.EXE by ZS6AWK can also be used. (based on serial.c ALEFNUL)
;           TERM under Norton Commander can also be used. The baudrate is set
;            in bios.asm
;
;           Test commands:   M - will print back a testmessage
;                            U - will flash UP LED (yellow)
;                            D - will flash DCD LED (green)
;                            C - will flash CAT LED (yellow)
;                            S - will flash RED STATUS (red)
;                            anychar - will echo and char+1 will be echo
;                                    - and will flash PTT LED (amber)
;                            Note green flashing LED is heartbeat (HB-green)
;
;           NOTE the green heartbeat LED must flash contineously !
;           It will communicate to PC with baudrate set in BIOS.ASM ie 19200baud
;
; Author  : Danie Brynard ZS6AWK
; Email   : BRYD@KIDD.CO.ZA
; Packet  : zs6awk@zs6ai.tvl.zaf.af
; File    : tstsci.asm
; Update  : Sat 23/3/96
; Target  : DSP56002EVM from Motorola REV2.2
;           + KC7WW or ZS6AWK Interface board (see TAPR netsig Upload)
; Notes   : Load BIOS.ASM ver-4/95 from KC7WW before loading program
; Status  : works 100%

; LED's on port B: (note colours defines/used by zs6awk)
PTT     equ     0
UP      equ     1
DCD     equ     2
CAT     equ     3
STA     equ     13

        include 'leonid'
        org     p:user_code

TSTSCI  move    #0,a1      ; normal mode NOT KISS
        opensc
        move    #>'T',x0
        putc
        move    #>'S',x0
        putc
        move    #>'T',x0
        putc
        move    #>'S',x0
        putc
        move    #>'C',x0
        putc
        move    #>'I',x0
        putc
        move    #>$0D,x0
        putc
        move    #>$0A,x0
        putc

        ; main program loop:
loop    
                 ;jsr     <TX_MES
                 ;jmp     loop
        getc
        jsr     <chk_cmd        ; see if 'M' was pressed
        ;
        jsr     <chk_UP         ; flash UP LED if U pressed
        jsr     <chk_DCD        ; flash DCD LED if D pressed
        jsr     <chk_CAT        ; flash CAT LED if C pressed
        ;
        jsr     <chk_STA        ; flash status LED if S pressed
        jsr     <chk_res        ; reset program

        putc                    ; echo character back
        jsr     <inc_x0
        putc
        
        bset   #PTT,x:$FFE4       ; toggle transmitter PTT control
        jsr    delay
        bclr   #PTT,x:$FFE4
        jmp     loop
        ; main loop end here

inc_x0  move    #>1,a           ; increment x0 by 1
        add     x0,a
        move    a,x0
        rts

delay   do      #500,_d_loop    ; create a 50ms delay
	rep     #2000           ; 100 us delay
	nop
_d_loop
        rts

; Subroutine to check for 'R' cmd
chk_res  move    #>'R',a
         cmp     x0,a
         jne     <_res_end
         jmp     TSTSCI
_res_end rts

; Subroutine to check for 'D' cmd and flash DCD:
chk_DCD  move    #>'D',a
         cmp     x0,a
         jne     <_dcd_end
         jsr     <flashdcd
_dcd_end rts
flashdcd bset   #DCD,x:$FFE4       ; toggle DCD LED
         jsr    delay
         bclr   #DCD,x:$FFE4
         rts

; Subroutine to check for 'C' cmd and flash CAT led:
chk_CAT  move    #>'C',a
         cmp     x0,a
         jne     <_cat_end
         jsr     <flashcat
_cat_end rts
flashcat bset   #CAT,x:$FFE4       ; toggle CAT LED
         jsr    delay
         bclr   #CAT,x:$FFE4
         rts

; Subroutine to check for 'U' cmd and flash UP:
chk_UP   move    #>'U',a
         cmp     x0,a
         jne     <_up_end
         jsr     <flashup
_up_end  rts
flashup  bset   #UP,x:$FFE4       ; toggle UP LED
         jsr    delay
         bclr   #UP,x:$FFE4
         rts

; Subroutine to check for 'S' cmd and flash status LED:
chk_STA  move    #>'S',a
         cmp     x0,a
         jne     <_sta_end
         jsr     <flashsta
_sta_end rts
flashsta bset   #STA,x:$FFE4       ; toggle status LED
         jsr    delay
         bclr   #STA,x:$FFE4
         rts

; Check for 'M' cmd and print then message:
chk_cmd  move    #>'M',a
         cmp     x0,a
         jne     <_chk_end
         jsr     <TX_MES
_chk_end rts

TX_MES   move    #>TABLE,r0   ; send message to terminal
         DO      #(E_TABLE-TABLE),_TX_MES
          move     p:(r0),a1   ;p:(r0) points to a 24bit memory address
          rep      #16
          ror      a1
          move     a1,x0
          putc                 ;send first character
          move     p:(r0),a1
          rep      #8
          ror      a1
          move     a1,x0
          putc                 ;send 2nd character
          move     p:(r0)+,a1  ;increment r0 pointer
          move     a1,x0
          putc                 ;send 3rd character
          nop
_TX_MES   nop
         rts

        org P:*   ;put data in program memory
; sign on message
TABLE   DC      'ABCDEF TEST MESSAGE [tstsci.asm] 0123456789'
        DC      $0D
        DC      $0A
E_TABLE
        end
